==> testdisk_7.1.orig.tar.bz2: testdisk-7.1/src/lang/qphotorec.it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="518"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Scegliere la destinazione in cui si desidera salvare i documenti recuperati.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Selezionare un documento raw</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Documenti raw (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Sys=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No harddisk found</source>
        <translation>Non è stato trovato alcun disco</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <translation>Non è stato trovato alcun disco
Si deve disporre di privilegi d&apos;amministratore per usare questo programma.
Con Win9x, usare piuttosto la versione DOS. 
Con Vista o superiore, selezionare questo programma, cliccare con il destro del mouse e scegliere &quot;Esegui come amministratore&quot;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No harddisk found
You need to be root to use PhotoRec.</source>
        <translation>Non è stato trovato alcun disco
Si deve disporre di privilegi di root per usare PhotoRec.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Nessun Disco!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="452"/>
        <source>Add a raw disk image...</source>
        <translation>Aggiungere un&apos;immagine raw del disco...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="458"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec è un software libero e viene fornito ASSOLUTAMENTE SENZA ALCUNA GARANZIA.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="459"/>
        <source>Please select a media to recover from</source>
        <translation>Selezionare un supporto dal quale eseguire l&apos;operazione di recupero</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>Per un ripristino corretto, la capacità del disco deve essere precisa.
Se un disco nell&apos;elenco ha una dimensione errata, controllare le impostazioni di HD jumper e BIOS 
detection, e installare gli aggiornamenti del sistema operativo e i driver del disco.
</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="469"/>
        <source>Flags</source>
        <translation>Flag</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="470"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="471"/>
        <source>File System</source>
        <translation>File System</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="488"/>
        <source>File System type</source>
        <translation>Tipo di File System</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="489"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>File system ext2/ext3/ext4</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="490"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="494"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Libero: ricerca di documenti unicamente nello spazio non allocato</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="495"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Completo: Estrazione dei documenti da tutta la partizione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="522"/>
        <source>&amp;Browse</source>
        <translation>&amp;Naviga</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="538"/>
        <source>&amp;Search</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="542"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Formati dei file</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="642"/>
        <source>Destination:</source>
        <translation>Destinazione:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="647"/>
        <source>Recovery completed</source>
        <translation>Recupero terminato</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="652"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Esaustiva %1 settori rimanenti (test %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="660"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Iterazione %1 - Lettura del settore %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="665"/>
        <source>%1/10 headers found</source>
        <translation>%1/10 intestazioni trovate</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="667"/>
        <source>%1 files found</source>
        <translation>%1 documenti trovati</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="540"/>
        <location filename="src/qphotorec.cpp" line="762"/>
        <source>&amp;Quit</source>
        <translation>&amp;Uscire</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="750"/>
        <source>File family</source>
        <translation>famiglia dei file</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="751"/>
        <source>Number of files recovered</source>
        <translation>numero dei file recuperati</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="834"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Impossibile creare il file!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="835"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Impossibile creare il file! Selezionare un&apos;altra destinazione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="854"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>QPhotoRec: Spazio insufficiente!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="855"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Spazio disponibile insufficiente. Liberare spazio su disco e/o scegliere un&apos;altra destinazione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="924"/>
        <source>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <translation>QPhotoRec è un software libero: può essere distribuito e/o modificato entro i termini della licenza GNU General Public License come pubblicata dalla Free Software Foundation, sia nella versione 2 della Licenza che, a propria scelta, in versioni successive.

QPhotoRec viene distribuito con la speranza che possa essere utile ma SENZA ALCUNA GARANZIA DI NESSUN TIPO, senza nemmeno la garanzia implicita di commerciabilità o idoneità per un particolare scopo. Vedere i dettagli della licenza per ulteriori chiarimenti.

Una copia della GNU General Public License è distribuita con QPhotoRec. In caso contrario se ne può ottenere una all&apos;indirizzo &lt;http://www.gnu.org/licenses/&gt;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="925"/>
        <source>QPhotoRec: About</source>
        <translation>QPhotoRec: A proposito</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="954"/>
        <source>File Formats</source>
        <translation>Formati dei file</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>&amp;Reset</source>
        <translation>&amp;Resettare</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="958"/>
        <source>Res&amp;tore</source>
        <translation>Ripri&amp;stinare</translation>
    </message>
</context>
</TS>

==> testdisk_7.2.orig.tar.bz2: testdisk-7.2/src/lang/qphotorec.it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="521"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Scegliere la destinazione in cui si desidera salvare i documenti recuperati.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Selezionare un documento raw</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Documenti raw (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Sys=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No hard disk found</source>
        <oldsource>No harddisk found</oldsource>
        <translation>Non è stato trovato alcun disco</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No hard disk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <oldsource>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</oldsource>
        <translation>Non è stato trovato alcun disco
Si deve disporre di privilegi d&apos;amministratore per usare questo programma.
Con Win9x, usare piuttosto la versione DOS. 
Con Vista o superiore, selezionare questo programma, cliccare con il destro del mouse e scegliere &quot;Esegui come amministratore&quot;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No hard disk found
You need to be root to use PhotoRec.</source>
        <oldsource>No harddisk found
You need to be root to use PhotoRec.</oldsource>
        <translation>Non è stato trovato alcun disco
Si deve disporre di privilegi di root per usare PhotoRec.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Nessun Disco!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="455"/>
        <source>Add a raw disk image...</source>
        <translation>Aggiungere un&apos;immagine raw del disco...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="461"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec è un software libero e viene fornito ASSOLUTAMENTE SENZA ALCUNA GARANZIA.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Please select a media to recover from</source>
        <translation>Selezionare un supporto dal quale eseguire l&apos;operazione di recupero</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="465"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>Per un ripristino corretto, la capacità del disco deve essere precisa.
Se un disco nell&apos;elenco ha una dimensione errata, controllare le impostazioni di HD jumper e BIOS 
detection, e installare gli aggiornamenti del sistema operativo e i driver del disco.
</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Flags</source>
        <translation>Flag</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="474"/>
        <source>File System</source>
        <translation>File System</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="475"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="476"/>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="491"/>
        <source>File System type</source>
        <translation>Tipo di File System</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="492"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>File system ext2/ext3/ext4</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="493"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="497"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Libero: ricerca di documenti unicamente nello spazio non allocato</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="498"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Completo: Estrazione dei documenti da tutta la partizione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="525"/>
        <source>&amp;Browse</source>
        <translation>&amp;Naviga</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;Search</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="544"/>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="545"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Formati dei file</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="645"/>
        <source>Destination:</source>
        <translation>Destinazione:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="650"/>
        <source>Recovery completed</source>
        <translation>Recupero terminato</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="655"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Esaustiva %1 settori rimanenti (test %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="663"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Iterazione %1 - Lettura del settore %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="668"/>
        <source>%1/10 headers found</source>
        <translation>%1/10 intestazioni trovate</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="670"/>
        <source>%1 files found</source>
        <translation>%1 documenti trovati</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="753"/>
        <source>File family</source>
        <translation>famiglia dei file</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="543"/>
        <location filename="src/qphotorec.cpp" line="765"/>
        <source>&amp;Quit</source>
        <translation>&amp;Uscire</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="754"/>
        <source>Number of files recovered</source>
        <translation>numero dei file recuperati</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="837"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Impossibile creare il file!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="838"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Impossibile creare il file! Selezionare un&apos;altra destinazione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="857"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>QPhotoRec: Spazio insufficiente!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="858"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Spazio disponibile insufficiente. Liberare spazio su disco e/o scegliere un&apos;altra destinazione</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="927"/>
        <source>QPhotoRec is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <oldsource>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</oldsource>
        <translation>QPhotoRec è un software libero: può essere distribuito e/o modificato entro i termini della licenza GNU General Public License come pubblicata dalla Free Software Foundation, sia nella versione 2 della Licenza che, a propria scelta, in versioni successive.

QPhotoRec viene distribuito con la speranza che possa essere utile ma SENZA ALCUNA GARANZIA DI NESSUN TIPO, senza nemmeno la garanzia implicita di commerciabilità o idoneità per un particolare scopo. Vedere i dettagli della licenza per ulteriori chiarimenti.

Una copia della GNU General Public License è distribuita con QPhotoRec. In caso contrario se ne può ottenere una all&apos;indirizzo &lt;http://www.gnu.org/licenses/&gt;.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="928"/>
        <source>QPhotoRec: About</source>
        <translation>QPhotoRec: A proposito</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>File Formats</source>
        <translation>Formati dei file</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="960"/>
        <source>&amp;Reset</source>
        <translation>&amp;Resettare</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="961"/>
        <source>Res&amp;tore</source>
        <translation>Ripri&amp;stinare</translation>
    </message>
</context>
</TS>
